pilas.fisica.ConstanteDeDistancia

Package pilas :: Module fisica :: Class ConstanteDeDistancia |
[hide private]
[frames] | no frames]

# Class ConstanteDeDistancia

source code

Representa una distancia fija entre dos figuras.

Esta constante es útil para representar ejes o barras que sostienen dos cuerpos. Por ejemplo, un eje entre dos ruedas en un automóvil:

    >>> circulo_1 = pilas.fisica.Circulo(-100, 0, 50)
    >>> circulo_2 = pilas.fisica.Circulo(100, 50, 50)
    >>> barra = pilas.fisica.ConstanteDeDistancia(circulo_1, circulo_2)

La distancia que tiene que respetarse en la misma que tienen las figuras en el momento en que se establece la constante.

Instance Methods | [hide private]
__init__(self, figura_1, figura_2, fisica=None, con_colision=True) Inicializa la constante. | source code
eliminar(self) | source code

Method Details | [hide private]

### __init__(self, figura_1, figura_2, fisica=None, con_colision=True) (Constructor) | source code
Inicializa la constante. :param figura_1: Una de las figuras a conectar por la constante. :param figura_2: La otra figura a conectar por la constante. :param fisica: Referencia al motor de física. :param con_colision: Indica si se permite colisión entre las dos figuras.